@@ -11,7 +11,7 @@ from .speechaudio import SpeechAudio
 import soundfile
 import numpy as np
 
-def file2speech(fileName, chn=1, sro=None):
+def file2speech(fileName, chn=1, sro=None, start=0, end=-1):
     
     if path.isfile(fileName):
         y, sr = soundfile.read(fileName)
@@ -21,6 +21,15 @@ def file2speech(fileName, chn=1, sro=None):
                 y = y[:,chn-1]
             else:
                 y = y[chn-1,:]
+                
+        idx1 = 0
+        idx2 = len(y)
+        if start > 0:
+            idx1 = int(start * sr)
+        if end > 0:
+            idx2 = int(end * sr)            
+        if idx1 > 0 or idx2 < len(y):
+            y = y[idx1:idx2]
         SpeechObject = SpeechAudio('signal', y.astype(float), 'sampling_frequency', sr)
         if sro is not None:
             if sr != sro:
