@@ -428,7 +428,7 @@ class Speaker:
     speaker_id = None
     L2 = None
     L2_level = None
-    sex = None
+    gender = None
     age = None
     utterance = []
     phonemes = []
@@ -436,6 +436,7 @@ class Speaker:
     pitch_stats = None
     intensity_stats = None
     formants = None
+    accent = None
 
     def __init__(self, *args):
         nargin = len(args)
