@@ -1160,7 +1160,7 @@ class VtNetwork:
                            limx = [0, tvec[-1]],
                            ax_share=ax)
 
-        h_handle.show()
+        #h_handle.show()
 
         return h_handle
 
@@ -1243,6 +1243,6 @@ class VtNetwork:
         #            limx = [0, tvec[-1]],
         #            ax_share=ax)
 
-        h_handle.show()
+        # h_handle.show()
 
         return h_handle
